#
# spec file for package libreiserfs
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libreiserfs
%define lname	libreiserfs-0_3-0
Url:            http://reiserfs.linux.kiev.ua
Version:        0.3.0.5
Release:        169.4
Summary:        ReiserFS File System Access Library
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Source:         http://ftp.roedu.net/pub/mirrors/ftp.namesys.com/pub/libreiserfs/progsreiserfs-%{version}.tar.bz2
Source1:        series
Source2:        baselibs.conf
Patch1:         reiserfs-strict-aliasing.diff
Patch2:         reiserfs-fix-warn.diff
Patch3:         reiserfs-dal-64bit.diff
Patch4:         libreiserfs-autoconf-fixups
Patch5:         libreiserfs-devel-fix
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         %install_info_prereq
BuildRequires:  libtool

%description
This is a library for reiserfs file system access and manipulation. The
primary goal is to develop the nice, full functionality library that
can be linked to any projects that needed reiserfs file system access.
These include GNU Parted, GNU GRUB, Yaboot, Partimage, and EVMS.

libreiserfs has a number of high level APIs for accessing reiserfs
file systems. There are main file system code, journal code, bitmap
code, directories and files access code, and device abstraction
layer.

progsreiserfs supports versions reiserfs versions 3.5 and 3.6 with
standard and relocated journal. It also supports all possible block
sizes supported by the kernel (2.4.18 with patches or 2.4.19).

Authors:
--------
    Yury Umanets <torque@ukrpost.net>
    Andrew Clausen <clausen@gnu.org>

%package -n %lname
Summary:        ReiserFS File System Access Library
Group:          System/Libraries
# added on 2012-05-24
Obsoletes:      libreiserfs < %version-%release
Provides:       libreiserfs = %version-%release

%description -n %lname
This is a library for reiserfs file system access and manipulation. The
primary goal is to develop the nice, full functionality library that
can be linked to any projects that needed reiserfs file system access.
These include GNU Parted, GNU GRUB, Yaboot, Partimage, and EVMS.

libreiserfs has a number of high level APIs for accessing reiserfs
file systems. There are main file system code, journal code, bitmap
code, directories and files access code, and device abstraction
layer.

%package progs
Summary:        ReiserFS Filesystem Access Tools
Group:          System/Filesystems
Conflicts:      reiserfs

%description progs
progsreiserfs supports reiserfs versions 3.5, 3.6 with standard and
relocated journal. Also all possible blocksizes which supported by
kernel (2.4.18 with patches or 2.4.19)

This package contains four programs that are simple frontends to
libreiserfs. There are: mkfs.reiserfs, resizefs.reiserfs,
cpfs.reiserfs, tunefs.reiserfs

Authors:
--------
    Yury Umanets <torque@ukrpost.net>
    Andrew Clausen <clausen@gnu.org>

%package devel
Summary:        ReiserFS Filesystem Access Tools
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       glibc-devel

%description devel
This is a library for reiserfs filesystem access and manipulation. The
primary goal is to develop the nice, full functionality library wich
might be linked against any projects which needed reiserfs filesystem
access. There are GNU Parted, GNU GRUB, Yaboot, Partimage, EVMS, etc.

Authors:
--------
    Yury Umanets <torque@ukrpost.net>
    Andrew Clausen <clausen@gnu.org>

%prep
%setup -n progsreiserfs-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
cp /usr/share/gettext/config.rpath .
libtoolize --force
autoreconf
export CFLAGS="$RPM_OPT_FLAGS"
#CFLAGS+=--with-capabilities
%configure --disable-static --enable-shared
make %{?_smp_mflags}

%check
#make check

%install
%makeinstall
%{__rm} -f %{buildroot}%{_libdir}/*.la

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libdal-0.3.so.0*
%_libdir/libreiserfs-0.3.so.0*

%files devel
%defattr(-,root,root)
%_includedir/dal
%_includedir/reiserfs
%{_libdir}/libdal.so
%{_libdir}/libreiserfs.so
%_datadir/aclocal/progsreiserfs.m4

%files progs
%defattr(-,root,root)
%_sbindir/*.reiserfs
%_mandir/man8/*.reiserfs.8*
%_mandir/man8/reiserfs.8*

%changelog
* Thu Aug 14 2014 fcrozat@suse.com
- Ensure libreiserfs-0_3-0-32bit obsoletes libreiserfs-32bit.
* Thu May 24 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Follow shlib naming policy, simplify file list
- Trim description, remove visions and deep implementation details
* Tue Nov 22 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Feb  1 2010 jengelh@medozas.de
- Package baselibs.conf
* Wed Nov 25 2009 crrodriguez@opensuse.org
- Do not package static libraries and "la" files
- fix -devel package dependencies
* Wed Feb 11 2009 jeffm@suse.de
- Fixed underquoted AC_CHECK_LIBREISERFS (bnc#458369)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Feb 29 2008 dmueller@suse.de
- various rpmlint fixes
* Sun Oct 15 2006 schwab@suse.de
- Make sure config.rpath is present.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 kukuk@suse.de
- Correct last fix for Bug [#140302]
- Create -devel subpackage
* Wed Dec 21 2005 mmj@suse.de
- This package conflicts with reiserfs
* Mon Dec 19 2005 garloff@suse.de
- Fix strict-aliasing issues.
- Fix some more compiler warnings.
* Sun Sep  4 2005 garloff@suse.de
- Initial creation of package (0.3.0.5).
- Use .so as extension for shared libs.
